..
      Copyright 2014-2015 OpenStack Foundation
      All Rights Reserved.

      Licensed under the Apache License, Version 2.0 (the "License"); you may
      not use this file except in compliance with the License. You may obtain
      a copy of the License at

          http://www.apache.org/licenses/LICENSE-2.0

      Unless required by applicable law or agreed to in writing, software
      distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
      WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
      License for the specific language governing permissions and limitations
      under the License.

===============================
Welcome to Tacker Documentation
===============================

Tacker is an OpenStack service for NFV Orchestration with a general purpose
VNF Manager to deploy and operate Virtual Network Functions (VNFs) and
Network Services on an NFV Platform. It is based on ETSI MANO Architectural
Framework.

Contents
--------

.. toctree::
   :maxdepth: 2

   install/index
   user/index
   admin/index
   configuration/index
   cli/index
   contributor/index
   reference/index

Release Notes
-------------

.. toctree::
   :maxdepth: 1

   Release Notes <https://docs.openstack.org/releasenotes/tacker>

Project Info
------------

* **Free software:** under the `Apache license <https://www.apache.org/licenses/LICENSE-2.0>`_
* **Tacker Service:** https://opendev.org/openstack/tacker
* **Tacker Horizon:** https://opendev.org/openstack/tacker-horizon
* **Tacker Specs:** https://opendev.org/openstack/tacker-specs
* **Tacker Specs Documentation:** https://specs.openstack.org/openstack/tacker-specs
* **Tacker Client Library:** https://opendev.org/openstack/python-tackerclient
* **Tacker Bugs:** https://bugs.launchpad.net/tacker
* **Client Bugs:** https://bugs.launchpad.net/python-tackerclient
* **Blueprints:** https://blueprints.launchpad.net/tacker

Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
